[![PyPI Version](https://badge.fury.io/py/homeassistant2xlsx.svg)](https://badge.fury.io/py/homeassistant2xlsx)
[![Python Build](https://github.com/c0fec0de/homeassistant2xlsx/actions/workflows/main.yml/badge.svg)](https://github.com/c0fec0de/homeassistant2xlsx/actions/workflows/main.yml)
[![Documentation](https://readthedocs.org/projects/homeassistant2xlsx/badge/?version=latest)](https://homeassistant2xlsx.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/c0fec0de/homeassistant2xlsx/badge.svg?branch=main)](https://coveralls.io/github/c0fec0de/homeassistant2xlsx?branch=main)
[![python-versions](https://img.shields.io/pypi/pyversions/homeassistant2xlsx.svg)](https://pypi.python.org/pypi/homeassistant2xlsx)
[![pylint](https://img.shields.io/badge/linter-pylint-%231674b1?style=flat)](https://www.pylint.org/)
[![black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# Add Home Assistant Data to Excel

This is a simple script which adds Home Assistant entities (i.e. `sensor`, `input_number`)
to a sheets in an Excel Workbook.

[Documentation](https://homeassistant2xlsx.readthedocs.io/en/latest/) -
[PyPI](https://pypi.org/project/homeassistant2xlsx/) -
[Sources](https://github.com/c0fec0de/homeassistant2xlsx) -
[Issues](https://github.com/c0fec0de/homeassistant2xlsx/issues)
